==> 0.0.1.tar.gz: lib/bloc/rewards_module/pages/loyality_type_page.dart <==

import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:flutter/material.dart';
import 'package:loyalty_foop/bloc/cubits/cubit_main.dart';
import 'package:loyalty_foop/bloc/rewards_module/pages/rewards_list_page.dart';
import 'package:loyalty_foop/bloc/rewards_module/pages/set_loyalty_details.dart';
import 'package:loyalty_foop/utils/app_buttons.dart';
import 'package:loyalty_foop/utils/searchBox.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:loyalty_foop/utils/colors.dart';
import 'package:loyalty_foop/utils/custom_app_bar.dart';
import 'package:loyalty_foop/utils/hexColors.dart';
import 'package:loyalty_foop/utils/localization.dart';
import 'package:loyalty_foop/utils/locator.dart';

import 'member_page.dart';
import 'package:loyalty_foop/utils/text_styling.dart';

class LoyaltyTypePage extends StatefulWidget {

  @override
  _LoyaltyTypePage createState() => _LoyaltyTypePage();
}

class _LoyaltyTypePage extends State<LoyaltyTypePage> {

  @override
  void initState() {
    super.initState();

  }

  late TextStyleElements styleElements;

  bool isSwitched =false;
  SharedPreferences? prefs = locator<SharedPreferences>();
  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: false,
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizations.of(context)!.translate("select_l_type"),
            actions: [

              appTextButton(
                onPressed: () {
                  Navigator.push(context,
                      MaterialPageRoute(builder: (BuildContext context) {
                        return SetLoyaltyDetails(

                        );
                      })).then((value) => {

                  });
                },
                child: Wrap(
                  direction: Axis.horizontal,
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    const Visibility(
                      visible: false,
                      child: Padding(
                        padding: EdgeInsets.only(right: 8.0),
                        child: SizedBox(
                          height: 15,
                          width: 15,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                    ),
                    Text(
                     AppLocalizations.of(context)!.translate("next"), style: styleElements
                          .headline6ThemeScalableW(context)
                          .copyWith(color: HexColor(AppColors.blueApp)),
                    ),
                    Icon(Icons.keyboard_arrow_right,
                        color: HexColor(AppColors.blueApp))
                  ],
                ),
                shape: CircleBorder(),
              ),
            ],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),
        body: ListView(
          children: [

            Padding(
              padding: const EdgeInsets.all(8.0),
              child: SearchBox(onvalueChanged: (String value) {  },hintText:"search")
            ),

            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      AppLocalizations.of(context)!
                          .translate("welcome_name"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      AppLocalizations.of(context)!
                          .translate("set_incentive"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:  Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      AppLocalizations.of(context)!
                          .translate("daily_session"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      AppLocalizations.of(context)!
                          .translate("daily_inc_d"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      AppLocalizations.of(context)!
                          .translate("weekly"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      AppLocalizations.of(context)!
                          .translate("weekly_sess"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:  Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'partner',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      AppLocalizations.of(context)!
                          .translate("monthly"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      AppLocalizations.of(context)!
                          .translate("monyhly_sess"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'team',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        AppLocalizations.of(context)!
                            .translate("yearly"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        AppLocalizations.of(context)!
                            .translate("yearly_sess"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        AppLocalizations.of(context)!
                            .translate("birthday"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        AppLocalizations.of(context)!
                            .translate("birthday_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        AppLocalizations.of(context)!
                            .translate("ani_wish"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        AppLocalizations.of(context)!
                            .translate("ani_wish_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        AppLocalizations.of(context)!
                            .translate("learning_wish"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        AppLocalizations.of(context)!
                            .translate("learning_wish_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                        leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                        title: Text(
                          AppLocalizations.of(context)!
                              .translate("sales_wish"),
                          style:
                          styleElements.subtitle1ThemeScalable(context),
                        ),
                        subtitle: Text(
                          AppLocalizations.of(context)!
                              .translate("sales_wish_des"),
                          style:
                          styleElements.subtitle2ThemeScalable(context),
                        ),

                        trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
          ],
        ),
      ),
    );
  }



}

==> 0.2.1.tar.gz: lib/bloc/rewards_module/pages/loyality_type_page.dart <==

import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:flutter/material.dart';
import 'package:loyalty_foop/bloc/cubits/cubit_main.dart';
import 'package:loyalty_foop/bloc/rewards_module/pages/rewards_list_page.dart';
import 'package:loyalty_foop/bloc/rewards_module/pages/set_loyalty_details.dart';
import 'package:loyalty_foop/utils/app_buttons.dart';
import 'package:loyalty_foop/utils/searchBox.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:loyalty_foop/utils/colors.dart';
import 'package:loyalty_foop/utils/custom_app_bar.dart';
import 'package:loyalty_foop/utils/hexColors.dart';
import 'package:loyalty_foop/utils/localization.dart';
import 'package:loyalty_foop/utils/locator.dart';

import 'member_page.dart';
import 'package:loyalty_foop/utils/text_styling.dart';

class LoyaltyTypePage extends StatefulWidget {

  @override
  _LoyaltyTypePage createState() => _LoyaltyTypePage();
}

class _LoyaltyTypePage extends State<LoyaltyTypePage> {

  @override
  void initState() {
    super.initState();

  }

  late TextStyleElements styleElements;
  AppLocalizations? localizations=locatorRewards<AppLocalizations>() ;
  bool isSwitched =false;
  SharedPreferences? prefs = locatorRewards<SharedPreferences>();
  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: false,
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: localizations!.translate("select_l_type"),
            actions: [

              appTextButton(
                onPressed: () {
                  Navigator.push(context,
                      MaterialPageRoute(builder: (BuildContext context) {
                        return SetLoyaltyDetails(

                        );
                      })).then((value) => {

                  });
                },
                child: Wrap(
                  direction: Axis.horizontal,
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    const Visibility(
                      visible: false,
                      child: Padding(
                        padding: EdgeInsets.only(right: 8.0),
                        child: SizedBox(
                          height: 15,
                          width: 15,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                    ),
                    Text(
                     localizations!.translate("next"), style: styleElements
                          .headline6ThemeScalableW(context)
                          .copyWith(color: HexColor(AppColors.blueApp)),
                    ),
                    Icon(Icons.keyboard_arrow_right,
                        color: HexColor(AppColors.blueApp))
                  ],
                ),
                shape: CircleBorder(),
              ),
            ],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),
        body: ListView(
          children: [

            Padding(
              padding: const EdgeInsets.all(8.0),
              child: SearchBox(onvalueChanged: (String value) {  },hintText:"search")
            ),

            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      localizations!
                          .translate("welcome_name"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      localizations!
                          .translate("set_incentive"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:  Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      localizations!
                          .translate("daily_session"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      localizations!
                          .translate("daily_inc_d"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'team',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      localizations!
                          .translate("weekly"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      localizations!
                          .translate("weekly_sess"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:  Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     RewardsListPage(type: 'post', messageTo: 'partner',),
                ),));



              },
              child: Card(
                elevation: 0,
                margin: EdgeInsets.only(left: 4, right: 4, bottom: 1),
                child: Padding(
                  padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                  child: ListTile(
                    leading: Image.asset('assets/appimages/change-password.png',width: 20,height: 20,),
                    title: Text(
                      localizations!
                          .translate("monthly"),
                      style: styleElements.subtitle1ThemeScalable(context),
                    ),

                    subtitle: Text(
                      localizations!
                          .translate("monyhly_sess"),
                      style:
                      styleElements.subtitle2ThemeScalable(context),
                    ),

                    trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                  ),
                ),
              ),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'team',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        localizations!
                            .translate("yearly"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        localizations!
                            .translate("yearly_sess"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        localizations!
                            .translate("birthday"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        localizations!
                            .translate("birthday_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        localizations!
                            .translate("ani_wish"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        localizations!
                            .translate("ani_wish_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing:Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                      title: Text(
                        localizations!
                            .translate("learning_wish"),
                        style:
                        styleElements.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        localizations!
                            .translate("learning_wish_des"),
                        style:
                        styleElements.subtitle2ThemeScalable(context),
                      ),

                      trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
            InkWell(
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:      RewardsListPage(type: 'chat', messageTo: 'partner',),
                ),));
              },
              child: Card(
                  elevation: 0,
                  margin:
                  EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                        leading: Image.asset('assets/appimages/account-settings.png',width: 20,height: 20,),
                        title: Text(
                          localizations!
                              .translate("sales_wish"),
                          style:
                          styleElements.subtitle1ThemeScalable(context),
                        ),
                        subtitle: Text(
                          localizations!
                              .translate("sales_wish_des"),
                          style:
                          styleElements.subtitle2ThemeScalable(context),
                        ),

                        trailing: Checkbox(onChanged: (bool? value) {  }, value: false,)
                    ),
                  )),
            ),
          ],
        ),
      ),
    );
  }



}
